@@ -102,7 +102,7 @@ def plotting(cfg: PlotmanConfig):
             if minp.isCreateNewJobParallelReady:
                 minp.ParallelWorker(cfg.scheduling, cfg.directories)
 
-            if cfg.apis.target_report_hook is not "":
+            if cfg.apis.target is not "":
                 PostDat(Job.get_jobs_json(minp.LsJobs), cfg)
             time.sleep(cfg.scheduling.polling_time_s)
 
